@@ -3,7 +3,6 @@
               comm = NULL, add = FALSE, dfun = vegdist,
               metaMDSdist = FALSE, na.action = na.fail, subset = NULL, ...)
 {
-    EPS <- sqrt(.Machine$double.eps)
     if (!inherits(formula, "formula"))
         stop("needs a model formula")
     if (missing(data)) {
@@ -34,7 +33,7 @@
             commname <- attr(X, "commname")
             comm <- eval.parent(parse(text=commname))
         } else {
-            X <- dfun(X, distance)
+            X <- dfun(X, distance, ...)
         }
     } else { # vdata name
         if (missing(comm))
@@ -86,6 +85,8 @@
     nm <- attr(X, "Labels")
     ## wcmdscale, optionally with additive adjustment
     X <- wcmdscale(X, x.ret = TRUE, add = add)
+    if(any(dim(X$points) == 0)) # there may be no positive dims
+        X$points <- matrix(0, NROW(X$points), 1)
     ## this may have been euclidified: update inertia
     if (!is.na(X$ac) && X$ac > sqrt(.Machine$double.eps))
         inertia <- paste(paste0(toupper(substring(X$add, 1, 1)),
@@ -97,7 +98,6 @@
     sol <- ordConstrained(X$points, d$Y, d$Z, method = "capscale")
 
     ## update for negative eigenvalues
-    poseig <- length(sol$CA$eig)
     if (any(X$eig < 0)) {
         negax <- X$eig[X$eig < 0]
         sol$CA$imaginary.chi <- sum(negax)
