@@ -54,9 +54,8 @@
         cex <- (cex[ord])[tt]
     if (length(col) > 1)
         col <- (col[ord])[tt]
-    ordiArgAbsorber(x[tt, , drop = FALSE], labels[tt], cex = cex, col = col,
-                    FUN = text, ...)
+    ordiArgAbsorber(x[tt, , drop = FALSE], labels = labels[tt], cex = cex,
+                    col = col, FUN = text, ...)
     names(tt) <- labels
-    tt <- tt[order(ord)]
-    invisible(tt)
+    invisible(tt[order(ord)])
 }
