@@ -11,7 +11,7 @@ options("prompt" = "> ", "continue" = "  ")
 
 
 ###################################################
-### code chunk number 2: intro-vegan.Rnw:71-74
+### code chunk number 2: intro-vegan.Rnw:73-76
 ###################################################
 library(vegan)
 data(dune)
@@ -19,15 +19,15 @@ ord <- decorana(dune)
 
 
 ###################################################
-### code chunk number 3: intro-vegan.Rnw:77-78
+### code chunk number 3: intro-vegan.Rnw:79-80
 ###################################################
 ord
 
 
 ###################################################
-### code chunk number 4: intro-vegan.Rnw:101-103
+### code chunk number 4: intro-vegan.Rnw:103-105
 ###################################################
-ord <- metaMDS(dune)
+ord <- metaMDS(dune, trace = FALSE)
 ord
 
 
@@ -38,7 +38,7 @@ plot(ord)
 
 
 ###################################################
-### code chunk number 6: intro-vegan.Rnw:118-119
+### code chunk number 6: intro-vegan.Rnw:120-121
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(ord)
@@ -49,27 +49,35 @@ plot(ord)
 ###################################################
 plot(ord, type = "n")
 points(ord, display = "sites", cex = 0.8, pch=21, col="red", bg="yellow")
-text(ord, display = "spec", cex=0.7, col="blue")
+text(ord, display = "species", cex=0.7, col="blue")
 
 
 ###################################################
-### code chunk number 8: intro-vegan.Rnw:140-141
+### code chunk number 8: intro-vegan.Rnw:142-143
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(ord, type = "n")
 points(ord, display = "sites", cex = 0.8, pch=21, col="red", bg="yellow")
-text(ord, display = "spec", cex=0.7, col="blue")
+text(ord, display = "species", cex=0.7, col="blue")
 
 
 ###################################################
-### code chunk number 9: intro-vegan.Rnw:206-208
+### code chunk number 9: intro-vegan.Rnw:151-154
+###################################################
+plot(ord, type = "n") |>
+points("sites", cex = 0.8, pch=21, col="red", bg="yellow") |>
+text("species", cex=0.7, col="blue")
+
+
+###################################################
+### code chunk number 10: intro-vegan.Rnw:226-228
 ###################################################
 data(dune.env)
 attach(dune.env)
 
 
 ###################################################
-### code chunk number 10: a
+### code chunk number 11: a
 ###################################################
 plot(ord, disp="sites", type="n")
 ordihull(ord, Management, col=1:4, lwd=3)
@@ -80,7 +88,7 @@ points(ord, disp="sites", pch=21, col="red", bg="yellow", cex=1.3)
 
 
 ###################################################
-### code chunk number 11: intro-vegan.Rnw:219-220
+### code chunk number 12: intro-vegan.Rnw:239-240
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(ord, disp="sites", type="n")
@@ -92,27 +100,27 @@ points(ord, disp="sites", pch=21, col="red", bg="yellow", cex=1.3)
 
 
 ###################################################
-### code chunk number 12: intro-vegan.Rnw:250-252
+### code chunk number 13: intro-vegan.Rnw:270-272
 ###################################################
 ord.fit <- envfit(ord ~ A1 + Management, data=dune.env, perm=999)
 ord.fit
 
 
 ###################################################
-### code chunk number 13: a
+### code chunk number 14: a
 ###################################################
 plot(ord, dis="site")
 plot(ord.fit)
 
 
 ###################################################
-### code chunk number 14: b
+### code chunk number 15: b
 ###################################################
 ordisurf(ord, A1, add=TRUE)
 
 
 ###################################################
-### code chunk number 15: intro-vegan.Rnw:268-270
+### code chunk number 16: intro-vegan.Rnw:288-290
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(ord, dis="site")
@@ -121,77 +129,77 @@ ordisurf(ord, A1, add=TRUE)
 
 
 ###################################################
-### code chunk number 16: intro-vegan.Rnw:290-292
+### code chunk number 17: intro-vegan.Rnw:310-312
 ###################################################
 ord <- cca(dune ~ A1 + Management, data=dune.env)
 ord
 
 
 ###################################################
-### code chunk number 17: a
+### code chunk number 18: a
 ###################################################
 plot(ord)
 
 
 ###################################################
-### code chunk number 18: intro-vegan.Rnw:299-300
+### code chunk number 19: intro-vegan.Rnw:319-320
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(ord)
 
 
 ###################################################
-### code chunk number 19: intro-vegan.Rnw:317-318
+### code chunk number 20: intro-vegan.Rnw:337-338
 ###################################################
 cca(dune ~ ., data=dune.env)
 
 
 ###################################################
-### code chunk number 20: intro-vegan.Rnw:327-328
+### code chunk number 21: intro-vegan.Rnw:347-348
 ###################################################
 anova(ord)
 
 
 ###################################################
-### code chunk number 21: intro-vegan.Rnw:336-337
+### code chunk number 22: intro-vegan.Rnw:356-357
 ###################################################
 anova(ord, by="term", permutations=199)
 
 
 ###################################################
-### code chunk number 22: intro-vegan.Rnw:342-343
+### code chunk number 23: intro-vegan.Rnw:362-363
 ###################################################
 anova(ord, by="mar", permutations=199)
 
 
 ###################################################
-### code chunk number 23: a
+### code chunk number 24: a
 ###################################################
 anova(ord, by="axis", permutations=499)
 
 
 ###################################################
-### code chunk number 24: intro-vegan.Rnw:355-357
+### code chunk number 25: intro-vegan.Rnw:375-377
 ###################################################
 ord <- cca(dune ~ A1 + Management + Condition(Moisture), data=dune.env)
 ord
 
 
 ###################################################
-### code chunk number 25: intro-vegan.Rnw:362-363
+### code chunk number 26: intro-vegan.Rnw:382-383
 ###################################################
 anova(ord, by="term", permutations=499)
 
 
 ###################################################
-### code chunk number 26: intro-vegan.Rnw:371-373
+### code chunk number 27: intro-vegan.Rnw:391-393
 ###################################################
 how <- how(nperm=499, plots = Plots(strata=dune.env$Moisture))
 anova(ord, by="term", permutations = how)
 
 
 ###################################################
-### code chunk number 27: intro-vegan.Rnw:377-378
+### code chunk number 28: intro-vegan.Rnw:397-398
 ###################################################
 detach(dune.env)
 
